@@ -1,8 +1,8 @@
 /// Assert one function output is greater than another.
 ///
-/// * When true, return Result `Ok(())`.
+/// * If true, return Result `Ok(())`.
 ///
-/// * When true, return Result `Err` with a diagnostic message.
+/// * Otherwise, return Result `Err` with a diagnostic message.
 ///
 /// # Examples
 ///
@@ -26,9 +26,15 @@
 
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
-///     "assertion failed: `assert_fn_gt!(function, left_input, right_value)`
-
-    function name: `i32::abs`,\n   left input: `1`,\n  right input: `-2`,\n  left output: `1`,\n right output: `2`".to_string());
+///     "assertion failed: `assert_fn_gt!(left_function, left_input, right_expr)`\n",
+///     " left_function label: `i32::abs`,\n",
+///     "   left_input label: `a`,\n",
+///     "   left_input debug: `1`,\n",
+///     "   right_expr label: `b`,\n",
+///     "   right_expr debug: `-2`,\n",
+///     "               left: `1`,\n",
+///     "              right: `-2`"
+/// );
 /// # }
 /// ```
 ///
@@ -39,24 +45,24 @@ macro_rules! assert_fn_gt_as_result {
         if a_output > $b_expr {
             Ok(())
         } else {
-            panic!("{}", msg_with_left_function_and_left_input_and_right_expr!(
-                "assertion failed",
-                "assert_fn_gt_other!",
+            Err(format!(
+                concat!(
+                    "assertion failed: `assert_fn_gt!(left_function, left_input, right_expr)`\n",
+                    " left_function label: `{}`,\n",
+                    "    left_input label: `{}`,\n",
+                    "    left_input debug: `{:?}`,\n",
+                    "    right_expr label: `{}`,\n",
+                    "    right_expr debug: `{:?}`,\n",
+                    "                left: `{:?}`,\n",
+                    "               right: `{:?}`"
+                ),
                 stringify!($function),
-                $a_input,
-                $b_expr,
+                stringify!($a_input), $a_input,
+                stringify!($b_expr), $b_expr,
                 a_output,
                 $b_expr
             ))
-        }
-    });
-    ($function:path, $a_input:expr, $b_expr:expr, $($arg:tt)+) => ({
-        let a_output = $function($a_input);
-        if a_output > $b_expr {
-            Ok(())
-        } else {
-            Err($($arg)+)
-        }
+    }
     });
 }
 
@@ -81,9 +87,7 @@ mod test_x_result {
         let x = assert_fn_gt_as_result!(i32::abs, a, b);
         assert_eq!(
             x.unwrap_err(),
-            "assertion failed: `assert_fn_gt!(function, left_input, right_value)`
-
-    function name: `i32::abs`,\n   left input: `1`,\n  right input: `-1`,\n  left output: `1`,\n right output: `1`"
+            "assertion failed: `assert_fn_gt!(left_function, left_input, right_value)`left_function label: `i32::abs`,\n   left_input label: `a`,\n   left_input debug: `1`,\n   right_expr label: `b`,\n   right_expr label: `-1`,\n        left: `1`,\n       output: `1`"
         );
     }
 
@@ -94,7 +98,7 @@ mod test_x_result {
         let x = assert_fn_gt_as_result!(i32::abs, a, b);
         assert_eq!(
             x.unwrap_err(),
-            "assertion failed: `assert_fn_gt!(function, left_input, right_value)`
+            "assertion failed: `assert_fn_gt!(left_function, left_input, right_value)`
 
     function name: `i32::abs`,\n   left input: `1`,\n  right input: `-2`,\n  left output: `1`,\n right output: `2`"
         );
@@ -137,7 +141,7 @@ mod test_x_result {
 
 /// Assert a function output is greater than another.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -161,12 +165,14 @@ mod test_x_result {
 /// });
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
-///     "assertion failed: `assert_fn_gt!(function, left_input, right_expr)`\n",
-///     "     function name: `i32::abs`,\n",
-///     "   left input: `1`,\n",
-///     "  right input: `-2`,\n",
-///     "         left: `1`,\n",
-///     "        right: `2`"
+///     "assertion failed: `assert_fn_gt!(left_function, left_input, right_expr)`\n",
+///     " left_function label: `i32::abs`,\n",
+///     "   left_input label: `a`,\n",
+///     "   left_input debug: `1`,\n",
+///     "   right_expr label: `b`,\n",
+///     "   right_expr debug: `-2`,\n",
+///     "               left: `1`,\n",
+///     "              right: `2`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -181,31 +187,3 @@ macro_rules! assert_fn_gt {
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-
-    #[test]
-    fn test_assert_fn_gt_x_arity_2_gt_success() {
-        let a: i32 = -2;
-        let b: i32 = 1;
-        let x = assert_fn_gt!(i32::abs, a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_fn_gt!(function, left_input, right_expr)`\n    function name: `i32::abs`,\n   left input: `1`,\n  right input: `-1`,\n         left: `1`,\n        right: `1`")]
-    fn test_assert_fn_gt_x_arity_2_eq_failure() {
-        let a: i32 = 1;
-        let b: i32 = -1;
-        let _x = assert_fn_gt!(i32::abs, a, b);
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_fn_gt!(function, left_input, right_expr)`\n    function name: `i32::abs`,\n   left input: `1`,\n  right input: `-2`,\n         left: `1`,\n        right: `2`")]
-    fn test_assert_fn_gt_x_arity_2_lt_failure() {
-        let a: i32 = 1;
-        let b: i32 = -2;
-        let _x = assert_fn_gt!(i32::abs, a, b);
-    }
-}
